# Copyright 1999-2020 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2

EAPI=7
inherit desktop git-r3 multilib savedconfig toolchain-funcs

DESCRIPTION="simple terminal implementation for X"
HOMEPAGE="https://st.suckless.org/"
EGIT_REPO_URI="https://github.com/bakkeby/st-flexipatch.git"

LICENSE="MIT-with-advertising"
SLOT="0"
KEYWORDS=""
IUSE="savedconfig"

RDEPEND="
	>=sys-libs/ncurses-6.0:0=
	media-libs/fontconfig
	x11-libs/libX11
	x11-libs/libXft
	~x11-terms/st-terminfo-${PV}
"
DEPEND="
	${RDEPEND}
	virtual/pkgconfig
	x11-base/xorg-proto
"
PATCHES=(
	"${FILESDIR}"/0001-move-config-to-st-flexipatch.patch
	"${FILESDIR}"/0002-disable-dynamic-colors.patch
	"${FILESDIR}"/0003-update-color-theme.patch
	"${FILESDIR}"/0004-dynamic-cursor-color.patch
	"${FILESDIR}"/0005-move-with-termmod-j-k.patch
	"${FILESDIR}"/0006-enable-more-patches-ig.patch
	"${FILESDIR}"/0007-scroll-mouse-patch.patch
	"${FILESDIR}"/0008-st-sync-patch.patch
	"${FILESDIR}"/0009-undercurl.patch
	"${FILESDIR}"/0010-anysize-simple.patch
	"${FILESDIR}"/0011-set-new-font-scale-binding.patch
	"${FILESDIR}"/0012-swapmouse.patch
	"${FILESDIR}"/0013-relative-border.patch
)

src_prepare() {
	default

	sed -i \
		-e "/^X11LIB/{s:/usr/X11R6/lib:/usr/$(get_libdir)/X11:}" \
		-e '/^STLDFLAGS/s|= .*|= $(LDFLAGS) $(LIBS)|g' \
		-e '/^X11INC/{s:/usr/X11R6/include:/usr/include/X11:}' \
		config.mk || die
	sed -i \
		-e '/tic/d' \
		Makefile || die

	restore_config config.h
}

src_configure() {
	sed -i \
		-e "s|pkg-config|$(tc-getPKG_CONFIG)|g" \
		config.mk || die

	tc-export CC
}

src_install() {
	emake DESTDIR="${D}" PREFIX="${EPREFIX}"/usr install

	make_desktop_entry ${PN} simpleterm utilities-terminal 'System;TerminalEmulator;' ''

	save_config config.h
}

pkg_postinst() {
	if ! [[ "${REPLACING_VERSIONS}" ]]; then
		elog "Please ensure a usable font is installed, like"
		elog "    media-fonts/corefonts"
		elog "    media-fonts/dejavu"
		elog "    media-fonts/urw-fonts"
	fi
}
