# Copyright 1999-2019 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2

EAPI=7
inherit git-r3 toolchain-funcs

DESCRIPTION="a dynamic window manager for X11"
HOMEPAGE="https://dwm.suckless.org/"
EGIT_REPO_URI="https://github.com/bakkeby/dwm-flexipatch"

LICENSE="MIT"
SLOT="0"
KEYWORDS=""
IUSE="xinerama"

RDEPEND="
	media-libs/fontconfig
	x11-libs/libX11
	x11-libs/libXft
	x11-libs/libxcb
	dev-libs/yajl
	xinerama? ( x11-libs/libXinerama )
"
DEPEND="
	${RDEPEND}
	xinerama? ( x11-base/xorg-proto )
"
PATCHES=(
    "${FILESDIR}"/0001-set-up-my-patches-and-config.patch
	"${FILESDIR}"/0002-set-urgent-color.patch
	"${FILESDIR}"/0003-more-config.patch
	"${FILESDIR}"/0004-edit-cyclelayout-keybinding.patch
	"${FILESDIR}"/0005-I-don-t-think-this-argument-is-required.patch
	"${FILESDIR}"/0006-decomment-libraries-used-by-enabled-patches.patch
	"${FILESDIR}"/0007-runsvdir-on-startup.patch
	"${FILESDIR}"/0008-browser-config.patch
	"${FILESDIR}"/0009-discord-window-rules.patch
	"${FILESDIR}"/0010-apply-one-rule-patch.patch
	"${FILESDIR}"/0011-add-agordejo-rule.patch
	"${FILESDIR}"/0012-start-easyeffects-on-tag-9.patch
	"${FILESDIR}"/0013-set-carla-to-tag-9.patch
	"${FILESDIR}"/0014-set-dmenucmd-to-rofi.patch
	"${FILESDIR}"/0015-enable-no-border-patch.patch
	"${FILESDIR}"/0016-force-swallow-from-alacritty.patch
	"${FILESDIR}"/0017-remove-browser-rules-and-add-permanent.patch
	"${FILESDIR}"/0018-sendmon-keeptag-patch.patch
	"${FILESDIR}"/0019-taglabels.patch
	"${FILESDIR}"/0020-better-taglabels.patch
	"${FILESDIR}"/0021-no-swallow-syncplay-mpv.patch
	"${FILESDIR}"/0022-add-thunderbird-and-ardour-labels.patch
	"${FILESDIR}"/0023-use-rofi-run.patch
	"${FILESDIR}"/0024-add-st-as-terminal.patch
	"${FILESDIR}"/0025-add-discord-icon-ig.patch
	"${FILESDIR}"/0026-set-correct-fontawesome-discord-character.patch
	"${FILESDIR}"/0027-set-pid-to-rofi.patch
)

src_prepare() {
	default

	sed -i \
		-e "s/ -Os / /" \
		-e "/^\(LDFLAGS\|CFLAGS\|CPPFLAGS\)/{s| = | += |g;s|-s ||g}" \
		config.mk || die
}

src_compile() {
	if use xinerama; then
		emake CC=$(tc-getCC) dwm dwm-msg
	else
		emake CC=$(tc-getCC) XINERAMAFLAGS="" XINERAMALIBS="" dwm dwm-msg
	fi
}

src_install() {
	emake DESTDIR="${D}" PREFIX="${EPREFIX}/usr" install

	dodoc README
}
